%%
% Accompaning measurement values for the paper
% "MAMPI-UWB  Multipath-assisted Device-freeLocalization with Magnitude
% and Phase Informationwith UWB Transceivers"
%%

%clear all 
%close all

%% Open the measurement files
load('cir_measurements_mampi-uwb.mat')

%%
% Measurement settings of the measurement hardware
measSettings.DW1000

%%
% Description of the measurement setup
measSettings.area

%%
% Description of the fields of the idle measurements
description.cir_idle

%%
% Description of the fields of the reference measurements
description.cir_reference

%%
% The actual measurements are found in cir_idle and cir_reference structures
% An example that reads out and plot the magnitude

% Plot the magnitude of an idle CIR measurement
meas_no = 1;
sample = cir_idle(meas_no).cir;

figure()
plot(abs(sample))
xlabel('t [ns]')
ylabel('|h_{raw}(t)|')

%%
% Example for reconstruction and alignment of the CIR measurement with sinc-interpolation
% see Section 4.2.3

% Plot the magnitude of an idle CIR measurement
meas_no = 1;

sample = cir_idle(meas_no).cir;
rx_lvl = cir_idle(meas_no).rx_lvl;
        
% Apply sinc-interpolation to CIR measurement
[reconstructed_cir, reconstructed_time] = reconstruct_cir(sample);

% Find the position, where the leading edge detection algorithm of the
% DW1000 found the start of the first peak
time_skip = find(reconstructed_time >= (cir_idle(meas_no).int_part + cir_idle(meas_no).frac_part*1/64)*1e-9);

cir = reconstructed_cir(time_skip(1):end);
time = reconstructed_time(time_skip(1):end);

figure()
plot(time, abs(cir))
xlabel('t [ns]')
ylabel('|h_{raw}(t)|')

%%
% Plot the magnitude of a CIR measurment of with a person standing at position_id 35
pos_id = 35;
sample = cir_reference(pos_id).cir.cir;

figure()
plot(abs(sample))
xlabel('t [ns]')
ylabel('|h_{raw}(t)|')
