function [reconstructed_cir, reconstructed_time] = reconstruct_cir(complex_cir)

    time_meas = [1:length(complex_cir)]*1e-9;

    %% Define sinc
    B = 500e6; % Hz
    T = 1/(2*B); % s
    dt_sinc = 1e-11; % Interpolation steps [s]
    time_sinc = [-10e-9:dt_sinc:10e-9];
    f_sinc = sin(pi*time_sinc/T)./(pi*time_sinc/T); % Definition of the sinc-function
    f_sinc(isnan(f_sinc)) = 1; % Prevent division by zero

    %% Adding zeros
    val_zeros = round((diff(time_meas(1:2))/dt_sinc)-1);
    compl_zeroAdd =[];
    for i_complmeas = 1:length(complex_cir)
        compl_zeroAdd = [compl_zeroAdd, complex_cir(i_complmeas)];
        if i_complmeas~=length(complex_cir)
            compl_zeroAdd = [compl_zeroAdd, zeros(1,val_zeros)];
        end
    end
    time_zeroAdd = time_meas(1): dt_sinc: time_meas(end);

    %% Filtering with sinc function
    reconstructed_cir = conv(compl_zeroAdd, f_sinc);
    reconstructed_time = time_zeroAdd(1)-(length(time_sinc)/2*dt_sinc): dt_sinc: time_zeroAdd(end)+(length(time_sinc)/2*dt_sinc);
    reconstructed_time = reconstructed_time(1:end-1)+dt_sinc/2; 
    
end

